<?php
/**
 * VW Hair Salon functions and definitions
 *
 * @package VW Hair Salon
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */

/* Theme Setup */
if ( ! function_exists( 'vw_hair_salon_setup' ) ) :
 
function vw_hair_salon_setup() {

	$GLOBALS['content_width'] = apply_filters( 'vw_hair_salon_content_width', 640 );
	
	load_theme_textdomain( 'vw-hair-salon', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo', array(
		'height'      => 240,
		'width'       => 240,
		'flex-height' => true,
	) );
	add_image_size('vw-hair-salon-homepage-thumb',240,145,true);
	
       register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'vw-hair-salon' ),
	) );

	add_theme_support( 'custom-background', array(
		'default-color' => 'ffffff'
	) );

	/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array('image','video','gallery','audio',) );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'css/editor-style.css', vw_hair_salon_font_url() ) );

	// Theme Activation Notice
	global $pagenow;
	
	if ( is_admin() && ('themes.php' == $pagenow) && isset( $_GET['activated'] ) ) {
		add_action( 'admin_notices', 'vw_hair_salon_activation_notice' );
	}
}
endif;
add_action( 'after_setup_theme', 'vw_hair_salon_setup' );


// Notice after Theme Activation
function vw_hair_salon_activation_notice() {
	echo '<div class="notice notice-success is-dismissible welcome-notice">';
		echo '<h3>'. esc_html__( 'Warm Greetings to you!!', 'vw-hair-salon' ) .'</h3>';
		echo '<p>'. esc_html__( 'Thank you for choosing VW Hair Salon theme. Would like to have you on our Welcome page so that you can reap all the benefits of our VW Hair Salon theme.', 'vw-hair-salon' ) .'</p>';
		echo '<p><a href="'. esc_url( admin_url( 'themes.php?page=vw_hair_salon_guide' ) ) .'" class="button button-primary">'. esc_html__( 'GET STARTED', 'vw-hair-salon' ) .'</a></p>';
	echo '</div>';
}

/* Theme Widgets Setup */
function vw_hair_salon_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'vw-hair-salon' ),
		'description'   => __( 'Appears on blog page sidebar', 'vw-hair-salon' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'vw-hair-salon' ),
		'description'   => __( 'Appears on page sidebar', 'vw-hair-salon' ),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar 3', 'vw-hair-salon' ),
		'description'   => __( 'Appears on page sidebar', 'vw-hair-salon' ),
		'id'            => 'sidebar-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 1', 'vw-hair-salon' ),
		'description'   => __( 'Appears on footer 1', 'vw-hair-salon' ),
		'id'            => 'footer-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 2', 'vw-hair-salon' ),
		'description'   => __( 'Appears on footer 2', 'vw-hair-salon' ),
		'id'            => 'footer-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 3', 'vw-hair-salon' ),
		'description'   => __( 'Appears on footer 3', 'vw-hair-salon' ),
		'id'            => 'footer-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Navigation 4', 'vw-hair-salon' ),
		'description'   => __( 'Appears on footer 4', 'vw-hair-salon' ),
		'id'            => 'footer-4',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Social Icon', 'vw-hair-salon' ),
		'description'   => __( 'Appears on top bar', 'vw-hair-salon' ),
		'id'            => 'social-icon',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'vw_hair_salon_widgets_init' );

/* Theme Font URL */
function vw_hair_salon_font_url() {
	$font_url = '';
	$font_family = array();
	$font_family[] = 'PT Sans:400,400i,700,700i';
	$font_family[] = 'Gabriela';

	$query_args = array(
		'family'	=> rawurlencode(implode('|',$font_family)),
	);
	$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
	return $font_url;
}

/* Theme enqueue scripts */
function vw_hair_salon_scripts() {
	wp_enqueue_style( 'vw-hair-salon-font', vw_hair_salon_font_url(), array() );
	wp_enqueue_style( 'bootstrap', get_template_directory_uri().'/css/bootstrap.css' );
	wp_enqueue_style( 'vw-hair-salon-basic-style', get_stylesheet_uri() );	
	wp_enqueue_style( 'vw-hair-salon-effect', get_template_directory_uri().'/css/effect.css' );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/css/fontawesome-all.css' );
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.js', array('jquery') ,'',true);
	wp_enqueue_script( 'vw-hair-salon-custom-scripts-jquery', get_template_directory_uri() . '/js/custom.js', array('jquery') );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	/* Enqueue the Dashicons script */
	wp_enqueue_style( 'dashicons' );
}
add_action( 'wp_enqueue_scripts', 'vw_hair_salon_scripts' );

function vw_hair_salon_ie_stylesheet(){
	wp_enqueue_style('vw-hair-salon-ie', get_template_directory_uri().'/css/ie.css');
	wp_style_add_data( 'vw-hair-salon-ie', 'conditional', 'IE' );
}
add_action('wp_enqueue_scripts','vw_hair_salon_ie_stylesheet');

/*radio button sanitization*/

function vw_hair_salon_sanitize_choices( $input, $setting ) {
    global $wp_customize; 
    $control = $wp_customize->get_control( $setting->id ); 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

function vw_hair_salon_sanitize_dropdown_pages( $page_id, $setting ) {
  // Ensure $input is an absolute integer.
  $page_id = absint( $page_id );
  // If $page_id is an ID of a published page, return it; otherwise, return the default.
  return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}

// Change number or products per row to 3
add_filter('loop_shop_columns', 'vw_hair_salon_loop_columns');
if (!function_exists('vw_hair_salon_loop_columns')) {
function vw_hair_salon_loop_columns() {
return 3; // 3 products per row
}
}

/* Excerpt Limit Begin */
function vw_hair_salon_string_limit_words($string, $word_limit) {
	$words = explode(' ', $string, ($word_limit + 1));
	if(count($words) > $word_limit)
	array_pop($words);
	return implode(' ', $words);
}

define('VW_HAIR_SALON_FREE_THEME_DOC','https://www.vwthemes.com/docs/free-vw-hair-salon/','vw-hair-salon');
define('VW_HAIR_SALON_SUPPORT','https://wordpress.org/support/theme/vw-hair-salon/','vw-hair-salon');
define('VW_HAIR_SALON_REVIEW','https://wordpress.org/support/theme/vw-hair-salon','vw-hair-salon');
define('VW_HAIR_SALON_BUY_NOW','https://www.vwthemes.com/themes/hair-salon-wordpress-theme/','vw-hair-salon');
define('VW_HAIR_SALON_LIVE_DEMO','https://vwthemes.net/hair-salon-pro/','vw-hair-salon');
define('VW_HAIR_SALON_PRO_DOC','https://vwthemes.com/docs/vw-hair-salon-pro/','vw-hair-salon');
define('VW_HAIR_SALON_FAQ','https://www.vwthemes.com/faqs/','vw-hair-salon');
define('VW_HAIR_SALON_CHILD_THEME','https://developer.wordpress.org/themes/advanced-topics/child-themes/','vw-hair-salon');
define('VW_HAIR_SALON_CREDIT','https://www.vwthemes.com/themes/free-hair-salon-wordpress-theme/','vw-hair-salon');

if ( ! function_exists( 'vw_hair_salon_credit' ) ) {
	function vw_hair_salon_credit(){
		echo "<a href=".esc_url(VW_HAIR_SALON_CREDIT)." target='_blank'>".esc_html__('Hair Salon WordPress Theme.','vw-hair-salon')."</a>";
	}
}

/* Implement the Custom Header feature. */
require get_template_directory() . '/inc/custom-header.php';

/* Custom template tags for this theme. */
require get_template_directory() . '/inc/template-tags.php';

/* Customizer additions. */
require get_template_directory() . '/inc/customizer.php';

/* Social Custom Widgets */
require get_template_directory() . '/inc/social-widgets/social-icon.php';

/* Implement the About theme page */
require get_template_directory() . '/inc/getstarted/getstarted.php';

/* typography */
require get_template_directory() . '/inc/typography/ctypo.php';